Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(278)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java

Issue 2005313002: Record UMA for Physical Web refresh resolve time (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java b/chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java
index 1349e0f4562175e94f856ad1b40053b97cade8e3..c28da2d48c38181833c13acf0f0ec66aefbfde4a 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/physicalweb/PhysicalWebUma.java
@@ -42,6 +42,7 @@ public class PhysicalWebUma {
private static final String PREFS_LOCATION_GRANTED_COUNT = "PhysicalWeb.Prefs.LocationGranted";
private static final String PWS_BACKGROUND_RESOLVE_TIMES = "PhysicalWeb.ResolveTime.Background";
private static final String PWS_FOREGROUND_RESOLVE_TIMES = "PhysicalWeb.ResolveTime.Foreground";
+ private static final String PWS_REFRESH_RESOLVE_TIMES = "PhysicalWeb.ResolveTime.Refresh";
private static final String OPT_IN_NOTIFICATION_PRESS_DELAYS =
"PhysicalWeb.ReferralDelay.OptInNotification";
private static final String STANDARD_NOTIFICATION_PRESS_DELAYS =
@@ -145,7 +146,8 @@ public class PhysicalWebUma {
}
/**
* Records a response time from PWS for a resolution during a foreground scan.
* @param duration The length of time PWS took to respond.
*/
public static void onForegroundPwsResolution(Context context, long duration) {
@@ -153,6 +155,15 @@ public class PhysicalWebUma {
}
/**
+ * Records a response time from PWS for a resolution during a foreground scan that is explicitly
+ * user-initiated through a refresh.
+ * @param duration The length of time PWS took to respond.
+ */
+ public static void onRefreshPwsResolution(Context context, long duration) {
+ handleTime(context, PWS_REFRESH_RESOLVE_TIMES, duration, TimeUnit.MILLISECONDS);
+ }
+
+ /**
* Records number of URLs displayed to a user when the URL list is first displayed.
* @param numUrls The number of URLs displayed to a user.
*/
@@ -324,6 +335,7 @@ public class PhysicalWebUma {
uploadActions(PREFS_LOCATION_GRANTED_COUNT);
uploadTimes(PWS_BACKGROUND_RESOLVE_TIMES, TimeUnit.MILLISECONDS);
uploadTimes(PWS_FOREGROUND_RESOLVE_TIMES, TimeUnit.MILLISECONDS);
+ uploadTimes(PWS_REFRESH_RESOLVE_TIMES, TimeUnit.MILLISECONDS);
uploadTimes(STANDARD_NOTIFICATION_PRESS_DELAYS, TimeUnit.MILLISECONDS);
uploadTimes(OPT_IN_NOTIFICATION_PRESS_DELAYS, TimeUnit.MILLISECONDS);
uploadCounts(TOTAL_URLS_INITIAL_COUNTS);
@@ -145,7 +146,8 @@ public class PhysicalWebUma {
}
/**
- * Records a response time from PWS for a resolution during a foreground scan.
+ * Records a response time from PWS for a resolution during a foreground scan that is not
+ * explicitly user-initiated through a refresh.
* @param duration The length of time PWS took to respond.
*/

Powered by Google App Engine
This is Rietveld 408576698